@@ -23,12 +23,12 @@ Syntax example:
 :note: There are no multiline steps, the description of the step must fit in
 one line.
 """
+
 from __future__ import annotations
 
+import glob
 import os.path
 
-import glob2
-
 from .parser import Feature, parse_feature
 
 # Global features dictionary
@@ -48,7 +48,7 @@ def get_feature(base_path: str, filename: str, encoding: str = "utf-8") -> Featu
            stored in the global variable cache to improve the performance
            when multiple scenarios are referencing the same file.
     """
-
+    __tracebackhide__ = True
     full_name = os.path.abspath(os.path.join(base_path, filename))
     feature = features.get(full_name)
     if not feature:
@@ -70,7 +70,9 @@ def get_features(paths: list[str], **kwargs) -> list[Feature]:
         if path not in seen_names:
             seen_names.add(path)
             if os.path.isdir(path):
-                features.extend(get_features(glob2.iglob(os.path.join(path, "**", "*.feature")), **kwargs))
+                features.extend(
+                    get_features(glob.iglob(os.path.join(path, "**", "*.feature"), recursive=True), **kwargs)
+                )
             else:
                 base, name = os.path.split(path)
                 feature = get_feature(base, name, **kwargs)
